@@ -36,9 +36,9 @@
 #include <glib/gutils.h>
 #include <libgnome/gnome-i18n.h>
 
-#include <gedit-menus.h>
-#include <gedit-plugin.h>
-#include <gedit-debug.h>
+#include <gedit/gedit-menus.h>
+#include <gedit/gedit-plugin.h>
+#include <gedit/gedit-debug.h>
 
 #include <libgnomeui/gnome-stock-icons.h>
 
@@ -48,17 +48,13 @@
 #include "gedit-spell-language-dialog.h"
 #include "gedit-automatic-spell-checker.h"
 
-#define SUBMENU_LABEL		N_("_Spelling...")
-#define SUBMENU_PATH		"/menu/Tools/ToolsOps_1/"
-#define SUBMENU_NAME		"SpellingMenu"	
-
-#define MENU_ITEM_LABEL		N_("_Check Spelling...")
-#define MENU_ITEM_PATH		"/menu/Tools/ToolsOps_1/SpellingMenu/"
+#define MENU_ITEM_LABEL		N_("_Check Spelling")
+#define MENU_ITEM_PATH		"/menu/Tools/ToolsOps_1/"
 #define MENU_ITEM_NAME		"SpellChecker"	
 #define MENU_ITEM_TIP		N_("Check the current document for incorrect spelling")
 
-#define MENU_ITEM_LABEL_AUTO	N_("_Auto Spellcheck")
-#define MENU_ITEM_PATH_AUTO	"/menu/Tools/ToolsOps_1/SpellingMenu/"
+#define MENU_ITEM_LABEL_AUTO	N_("_Autocheck Spelling")
+#define MENU_ITEM_PATH_AUTO	"/menu/Tools/ToolsOps_1/"
 #define MENU_ITEM_NAME_AUTO	"AutoSpellChecker"	
 #define MENU_ITEM_TIP_AUTO	N_("Automatically spell-check the current document")
 
@@ -68,7 +64,6 @@
 #define MENU_ITEM_TIP_LANG	N_("Set the language of the current document")
 
 G_MODULE_EXPORT GeditPluginState update_ui (GeditPlugin *plugin, BonoboWindow *window);
-G_MODULE_EXPORT GeditPluginState destroy (GeditPlugin *pd);
 G_MODULE_EXPORT GeditPluginState activate (GeditPlugin *pd);
 G_MODULE_EXPORT GeditPluginState deactivate (GeditPlugin *pd);
 G_MODULE_EXPORT GeditPluginState init (GeditPlugin *pd);
@@ -743,14 +738,6 @@ update_ui (GeditPlugin *plugin, BonoboWindow *window)
 
 	return PLUGIN_OK;
 }
-
-G_MODULE_EXPORT GeditPluginState
-destroy (GeditPlugin *plugin)
-{
-	gedit_debug (DEBUG_PLUGINS, "");
-
-	return PLUGIN_OK;
-}
 	
 G_MODULE_EXPORT GeditPluginState
 activate (GeditPlugin *pd)
@@ -765,10 +752,6 @@ activate (GeditPlugin *pd)
         {
 		BonoboUIComponent *ui_component;
 
-		gedit_menus_add_submenu (BONOBO_WINDOW (top_windows->data),
-				     SUBMENU_PATH, SUBMENU_NAME,
-				     SUBMENU_LABEL);
-
 		gedit_menus_add_menu_item (BONOBO_WINDOW (top_windows->data),
 				     MENU_ITEM_PATH, MENU_ITEM_NAME,
 				     MENU_ITEM_LABEL, MENU_ITEM_TIP, GTK_STOCK_SPELL_CHECK,
@@ -803,9 +786,6 @@ deactivate (GeditPlugin *pd)
 {
 	gedit_menus_remove_menu_item_all (MENU_ITEM_PATH, MENU_ITEM_NAME);
 	gedit_menus_remove_menu_item_all (MENU_ITEM_PATH_AUTO, MENU_ITEM_NAME_AUTO);
-
-	gedit_menus_remove_submenu_all (SUBMENU_PATH, SUBMENU_NAME);
-
 	gedit_menus_remove_menu_item_all (MENU_ITEM_PATH_LANG, MENU_ITEM_NAME_LANG);
 
 	return PLUGIN_OK;
@@ -816,12 +796,7 @@ init (GeditPlugin *pd)
 {
 	/* initialize */
 	gedit_debug (DEBUG_PLUGINS, "");
-     
-	pd->name = _("Spell checker");
-	pd->desc = _("Checks the spelling of the current document.");
-	pd->author = "Paolo Maggi <maggi@athena.polito.it>";
-	pd->copyright = _("Copyright (C) 2002 - Paolo Maggi");
-	
+     	
 	pd->private_data = NULL;
 
 	if (spell_checker_id == 0)
